# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class EnterpriseAdminAccessEnum(object):

    """Implementation of the 'EnterpriseAdminAccess' enum.

    Whether or not an SSID is accessible by 'enterprise' administrators
    ('access disabled' or 'access enabled')

    Attributes:
        ENUM_ACCESS DISABLED: TODO: type description here.
        ENUM_ACCESS ENABLED: TODO: type description here.

    """

    ENUM_ACCESS_DISABLED = 'access disabled'

    ENUM_ACCESS_ENABLED = 'access enabled'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class Hub(object):

    """Implementation of the 'Hub' model.

    TODO: type model description here.

    Attributes:
        hub_id (string): The network ID of the hub.
        use_default_route (bool): Only valid in 'spoke' mode. Indicates
            whether default route traffic should be sent to this hub.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "hub_id":'hubId',
        "use_default_route":'useDefaultRoute'
    }

    def __init__(self,
                 hub_id=None,
                 use_default_route=None):
        """Constructor for the Hub class"""

        # Initialize members of the class
        self.hub_id = hub_id
        self.use_default_route = use_default_route


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        hub_id = dictionary.get('hubId')
        use_default_route = dictionary.get('useDefaultRoute')

        # Return an object of this model
        return cls(hub_id,
                   use_default_route)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class CombineOrganizationNetworks(object):

    """Implementation of the 'combineOrganizationNetworks' model.

    TODO: type model description here.

    Attributes:
        name (string): The name of the combined network
        network_ids (list of string): A list of the network IDs that will be
            combined. If an ID of a combined network is included in this list,
            the other networks in the list will be grouped into that network
        enrollment_string (string): A unique identifier which can be used for
            device enrollment or easy access through the Meraki SM
            Registration page or the Self Service Portal. Please note that
            changing this field may cause existing bookmarks to break. All
            networks that are part of this combined network will have their
            enrollment string appended by '-network_type'. If left empty, all
            exisitng enrollment strings will be deleted.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name":'name',
        "network_ids":'networkIds',
        "enrollment_string":'enrollmentString'
    }

    def __init__(self,
                 name=None,
                 network_ids=None,
                 enrollment_string=None):
        """Constructor for the CombineOrganizationNetworks class"""

        # Initialize members of the class
        self.name = name
        self.network_ids = network_ids
        self.enrollment_string = enrollment_string


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get('name')
        network_ids = dictionary.get('networkIds')
        enrollment_string = dictionary.get('enrollmentString')

        # Return an object of this model
        return cls(name,
                   network_ids,
                   enrollment_string)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class MoveOrganizationLicenses(object):

    """Implementation of the 'moveOrganizationLicenses' model.

    TODO: type model description here.

    Attributes:
        dest_organization_id (string): The ID of the organization to move the
            licenses to
        license_ids (list of string): A list of IDs of licenses to move to the
            new organization

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "dest_organization_id":'destOrganizationId',
        "license_ids":'licenseIds'
    }

    def __init__(self,
                 dest_organization_id=None,
                 license_ids=None):
        """Constructor for the MoveOrganizationLicenses class"""

        # Initialize members of the class
        self.dest_organization_id = dest_organization_id
        self.license_ids = license_ids


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        dest_organization_id = dictionary.get('destOrganizationId')
        license_ids = dictionary.get('licenseIds')

        # Return an object of this model
        return cls(dest_organization_id,
                   license_ids)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import test_meraki.models.admin_settings
import test_meraki.models.help_settings_1

class UpdateOrganizationBrandingPolicy(object):

    """Implementation of the 'updateOrganizationBrandingPolicy' model.

    TODO: type model description here.

    Attributes:
        name (string): Name of the Dashboard branding policy.
        enabled (bool): Boolean indicating whether this policy is enabled.
        admin_settings (AdminSettings): Settings for describing which kinds of
            admins this policy applies to.
        help_settings (HelpSettings1): Settings for describing the
            modifications to various Help page features. Each property in this
            object accepts one of     'default or inherit' (do not modify
            functionality), 'hide' (remove the section from Dashboard), or
            'show' (always show     the section on Dashboard). Some properties
            in this object also accept custom HTML used to replace the section
            on     Dashboard; see the documentation for each property to see
            the allowed values.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name":'name',
        "enabled":'enabled',
        "admin_settings":'adminSettings',
        "help_settings":'helpSettings'
    }

    def __init__(self,
                 name=None,
                 enabled=None,
                 admin_settings=None,
                 help_settings=None):
        """Constructor for the UpdateOrganizationBrandingPolicy class"""

        # Initialize members of the class
        self.name = name
        self.enabled = enabled
        self.admin_settings = admin_settings
        self.help_settings = help_settings


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get('name')
        enabled = dictionary.get('enabled')
        admin_settings = test_meraki.models.admin_settings.AdminSettings.from_dictionary(dictionary.get('adminSettings')) if dictionary.get('adminSettings') else None
        help_settings = test_meraki.models.help_settings_1.HelpSettings1.from_dictionary(dictionary.get('helpSettings')) if dictionary.get('helpSettings') else None

        # Return an object of this model
        return cls(name,
                   enabled,
                   admin_settings,
                   help_settings)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class Alert(object):

    """Implementation of the 'Alert' model.

    TODO: type model description here.

    Attributes:
        mtype (string): The type of alert
        enabled (bool): A boolean depicting if the alert is turned on or off
        alert_destinations (object): A hash of destinations for this specific
            alert. Keys include: emails: A list of emails that will recieve
            information about the alert, allAdmins: If true, then all network
            admins will receive emails, and snmp: If true, then an SNMP trap
            will be sent if there is an SNMP trap server configured for this
            network.
        filters (object): A hash of specific configuration data for the alert.
            Only filters specific to the alert will be updated.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "mtype":'type',
        "enabled":'enabled',
        "alert_destinations":'alertDestinations',
        "filters":'filters'
    }

    def __init__(self,
                 mtype=None,
                 enabled=None,
                 alert_destinations=None,
                 filters=None):
        """Constructor for the Alert class"""

        # Initialize members of the class
        self.mtype = mtype
        self.enabled = enabled
        self.alert_destinations = alert_destinations
        self.filters = filters


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        mtype = dictionary.get('type')
        enabled = dictionary.get('enabled')
        alert_destinations = dictionary.get('alertDestinations')
        filters = dictionary.get('filters')

        # Return an object of this model
        return cls(mtype,
                   enabled,
                   alert_destinations,
                   filters)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class L7FirewallRule(object):

    """Implementation of the 'L7FirewallRule' model.

    TODO: type model description here.

    Attributes:
        policy (Policy1Enum): The policy applied to matching traffic. Must be
            'deny'.
        mtype (Type1Enum): Type of the L7 Rule. Must be 'application',
            'applicationCategory', 'host', 'port' or 'ipRange'
        value (string): The 'value' of what you want to block. If 'type' is
            'host', 'port' or 'ipRange', 'value' must be a string matching
            either a hostname (e.g. somewhere.com), a port (e.g. 8080), or an
            IP range (e.g. 192.1.0.0/16). If 'type' is 'application' or
            'applicationCategory', then 'value' must be an object with an ID
            for the application.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "policy":'policy',
        "mtype":'type',
        "value":'value'
    }

    def __init__(self,
                 policy=None,
                 mtype=None,
                 value=None):
        """Constructor for the L7FirewallRule class"""

        # Initialize members of the class
        self.policy = policy
        self.mtype = mtype
        self.value = value


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        policy = dictionary.get('policy')
        mtype = dictionary.get('type')
        value = dictionary.get('value')

        # Return an object of this model
        return cls(policy,
                   mtype,
                   value)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from test_meraki.api_helper import APIHelper
from test_meraki.configuration import Configuration
from test_meraki.controllers.base_controller import BaseController
from test_meraki.http.auth.custom_header_auth import CustomHeaderAuth

class TrafficShapingController(BaseController):

    """A Controller to access Endpoints in the test_meraki API."""


    def update_network_ssid_traffic_shaping(self,
                                            network_id,
                                            number,
                                            update_network_ssid_traffic_shaping=None):
        """Does a PUT request to /networks/{networkId}/ssids/{number}/trafficShaping.

        Update the traffic shaping settings for an SSID on an MR network

        Args:
            network_id (string): TODO: type description here. Example: 
            number (string): TODO: type description here. Example: 
            update_network_ssid_traffic_shaping
                (UpdateNetworkSsidTrafficShaping, optional): TODO: type
                description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/ssids/{number}/trafficShaping'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'number': number
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(update_network_ssid_traffic_shaping))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_ssid_traffic_shaping(self,
                                         network_id,
                                         number):
        """Does a GET request to /networks/{networkId}/ssids/{number}/trafficShaping.

        Display the traffic shaping settings for a SSID on an MR network

        Args:
            network_id (string): TODO: type description here. Example: 
            number (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/ssids/{number}/trafficShaping'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'number': number
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def update_network_traffic_shaping(self,
                                       network_id,
                                       update_network_traffic_shaping=None):
        """Does a PUT request to /networks/{networkId}/trafficShaping.

        Update the traffic shaping settings for an MX network

        Args:
            network_id (string): TODO: type description here. Example: 
            update_network_traffic_shaping (UpdateNetworkTrafficShaping,
                optional): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/trafficShaping'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(update_network_traffic_shaping))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_traffic_shaping(self,
                                    network_id):
        """Does a GET request to /networks/{networkId}/trafficShaping.

        Display the traffic shaping settings for an MX network

        Args:
            network_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/trafficShaping'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_traffic_shaping_application_categories(self,
                                                           network_id):
        """Does a GET request to /networks/{networkId}/trafficShaping/applicationCategories.

        Returns the application categories for traffic shaping rules.

        Args:
            network_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/trafficShaping/applicationCategories'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_traffic_shaping_dscp_tagging_options(self,
                                                         network_id):
        """Does a GET request to /networks/{networkId}/trafficShaping/dscpTaggingOptions.

        Returns the available DSCP tagging options for your traffic shaping
        rules.

        Args:
            network_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/trafficShaping/dscpTaggingOptions'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body



# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class WpaEncryptionModeEnum(object):

    """Implementation of the 'WpaEncryptionMode' enum.

    The types of WPA encryption. ('WPA1 and WPA2' or 'WPA2 only')

    Attributes:
        ENUM_WPA1 AND WPA2: TODO: type description here.
        ENUM_WPA2 ONLY: TODO: type description here.

    """

    ENUM_WPA1_AND_WPA2 = 'WPA1 and WPA2'

    ENUM_WPA2_ONLY = 'WPA2 only'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class WipeNetworkSmDevice(object):

    """Implementation of the 'wipeNetworkSmDevice' model.

    TODO: type model description here.

    Attributes:
        wifi_mac (string): The wifiMac of the device to be wiped.
        id (string): The id of the device to be wiped.
        serial (string): The serial of the device to be wiped.
        pin (int): The pin number (a six digit value) for wiping a macOS
            device. Required only for macOS devices.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "wifi_mac":'wifiMac',
        "id":'id',
        "serial":'serial',
        "pin":'pin'
    }

    def __init__(self,
                 wifi_mac=None,
                 id=None,
                 serial=None,
                 pin=None):
        """Constructor for the WipeNetworkSmDevice class"""

        # Initialize members of the class
        self.wifi_mac = wifi_mac
        self.id = id
        self.serial = serial
        self.pin = pin


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        wifi_mac = dictionary.get('wifiMac')
        id = dictionary.get('id')
        serial = dictionary.get('serial')
        pin = dictionary.get('pin')

        # Return an object of this model
        return cls(wifi_mac,
                   id,
                   serial,
                   pin)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class DataProtectionRequestsSubtabEnum(object):

    """Implementation of the 'DataProtectionRequestsSubtab' enum.

    The 'Help -> Data protection requests' Dashboard subtab on which requests
    to delete, restrict, or export end-user data can
        be audited. Can be one of 'default or inherit', 'hide' or 'show'.

    Attributes:
        ENUM_DEFAULT OR INHERIT: TODO: type description here.
        HIDE: TODO: type description here.
        SHOW: TODO: type description here.

    """

    ENUM_DEFAULT_OR_INHERIT = 'default or inherit'

    HIDE = 'hide'

    SHOW = 'show'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

class SplashPageEnum(object):

    """Implementation of the 'SplashPage' enum.

    The type of splash page for the SSID ('None', 'Click-through splash page',
    'Billing', 'Password-protected with Meraki RADIUS', 'Password-protected
    with custom RADIUS', 'Password-protected with Active Directory',
    'Password-protected with LDAP', 'SMS authentication', 'Systems Manager
    Sentry', 'Facebook Wi-Fi', 'Google OAuth' or 'Sponsored guest'). This
    attribute is not supported for template children.

    Attributes:
        NONE: TODO: type description here.
        ENUM_CLICKTHROUGH SPLASH PAGE: TODO: type description here.
        BILLING: TODO: type description here.
        ENUM_PASSWORDPROTECTED WITH MERAKI RADIUS: TODO: type description
            here.
        ENUM_PASSWORDPROTECTED WITH CUSTOM RADIUS: TODO: type description
            here.
        ENUM_PASSWORDPROTECTED WITH ACTIVE DIRECTORY: TODO: type description
            here.
        ENUM_PASSWORDPROTECTED WITH LDAP: TODO: type description here.
        ENUM_SMS AUTHENTICATION: TODO: type description here.
        ENUM_SYSTEMS MANAGER SENTRY: TODO: type description here.
        ENUM_FACEBOOK WIFI: TODO: type description here.
        ENUM_GOOGLE OAUTH: TODO: type description here.
        ENUM_SPONSORED GUEST: TODO: type description here.

    """

    ENUM_NONE = 'None'

    ENUM_CLICKTHROUGH_SPLASH_PAGE = 'Click-through splash page'

    BILLING = 'Billing'

    ENUM_PASSWORDPROTECTED_WITH_MERAKI_RADIUS = 'Password-protected with Meraki RADIUS'

    ENUM_PASSWORDPROTECTED_WITH_CUSTOM_RADIUS = 'Password-protected with custom RADIUS'

    ENUM_PASSWORDPROTECTED_WITH_ACTIVE_DIRECTORY = 'Password-protected with Active Directory'

    ENUM_PASSWORDPROTECTED_WITH_LDAP = 'Password-protected with LDAP'

    ENUM_SMS_AUTHENTICATION = 'SMS authentication'

    ENUM_SYSTEMS_MANAGER_SENTRY = 'Systems Manager Sentry'

    ENUM_FACEBOOK_WIFI = 'Facebook Wi-Fi'

    ENUM_GOOGLE_OAUTH = 'Google OAuth'

    ENUM_SPONSORED_GUEST = 'Sponsored guest'




# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from test_meraki.api_helper import APIHelper
from test_meraki.configuration import Configuration
from test_meraki.controllers.base_controller import BaseController
from test_meraki.http.auth.custom_header_auth import CustomHeaderAuth

class NetworksController(BaseController):

    """A Controller to access Endpoints in the test_meraki API."""


    def get_network(self,
                    network_id):
        """Does a GET request to /networks/{networkId}.

        Return a network

        Args:
            network_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def update_network(self,
                       network_id,
                       update_network=None):
        """Does a PUT request to /networks/{networkId}.

        Update a network

        Args:
            network_id (string): TODO: type description here. Example: 
            update_network (UpdateNetwork, optional): TODO: type description
                here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(update_network))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def delete_network(self,
                       network_id):
        """Does a DELETE request to /networks/{networkId}.

        Delete a network

        Args:
            network_id (string): TODO: type description here. Example: 

        Returns:
            void: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.delete(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

    def get_network_access_policies(self,
                                    network_id):
        """Does a GET request to /networks/{networkId}/accessPolicies.

        List the access policies for this network. Only valid for MS
        networks.

        Args:
            network_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/accessPolicies'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_air_marshal(self,
                                network_id,
                                t_0=None,
                                timespan=None):
        """Does a GET request to /networks/{networkId}/airMarshal.

        List Air Marshal scan results from a network

        Args:
            network_id (string): TODO: type description here. Example: 
            t_0 (string, optional): The beginning of the timespan for the
                data. The maximum lookback period is 31 days from today.
            timespan (float, optional): The timespan for which the information
                will be fetched. If specifying timespan, do not specify
                parameter t0. The value must be in seconds and be less than or
                equal to 31 days. The default is 7 days.

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/airMarshal'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            't0': t_0,
            'timespan': timespan
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def create_bind_network(self,
                            network_id,
                            bind_network):
        """Does a POST request to /networks/{networkId}/bind.

        Bind a network to a template.

        Args:
            network_id (string): TODO: type description here. Example: 
            bind_network (BindNetwork): TODO: type description here. Example:
                
        Returns:
            void: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/bind'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(bind_network))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

    def get_network_bluetooth_settings(self,
                                       network_id):
        """Does a GET request to /networks/{networkId}/bluetoothSettings.

        Return the Bluetooth settings for a network. <a
        href="https://documentation.meraki.com/MR/Bluetooth/Bluetooth_Low_Energ
        y_(BLE)">Bluetooth settings</a> must be enabled on the network.

        Args:
            network_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/bluetoothSettings'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def update_network_bluetooth_settings(self,
                                          network_id,
                                          update_network_bluetooth_settings=None):
        """Does a PUT request to /networks/{networkId}/bluetoothSettings.

        Update the Bluetooth settings for a network. See the docs page for <a
        href="https://documentation.meraki.com/MR/Bluetooth/Bluetooth_Low_Energ
        y_(BLE)">Bluetooth settings</a>.

        Args:
            network_id (string): TODO: type description here. Example: 
            update_network_bluetooth_settings (UpdateNetworkBluetoothSettings,
                optional): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/bluetoothSettings'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(update_network_bluetooth_settings))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_site_to_site_vpn(self,
                                     network_id):
        """Does a GET request to /networks/{networkId}/siteToSiteVpn.

        Return the site-to-site VPN settings of a network. Only valid for MX
        networks.

        Args:
            network_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/siteToSiteVpn'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def update_network_site_to_site_vpn(self,
                                        network_id,
                                        update_network_site_to_site_vpn):
        """Does a PUT request to /networks/{networkId}/siteToSiteVpn.

        Update the site-to-site VPN settings of a network. Only valid for MX
        networks in NAT mode.

        Args:
            network_id (string): TODO: type description here. Example: 
            update_network_site_to_site_vpn (UpdateNetworkSiteToSiteVpn):
                TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/siteToSiteVpn'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.put(_query_url, headers=_headers, parameters=APIHelper.json_serialize(update_network_site_to_site_vpn))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def create_split_network(self,
                             network_id):
        """Does a POST request to /networks/{networkId}/split.

        Split a combined network into individual networks for each type of
        device

        Args:
            network_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/split'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.post(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_traffic(self,
                            network_id,
                            t_0=None,
                            timespan=None,
                            device_type=None):
        """Does a GET request to /networks/{networkId}/traffic.

            The traffic analysis data for this network.
            <a
            href="https://documentation.meraki.com/MR/Monitoring_and_Reporting/
            Hostname_Visibility">Traffic Analysis with Hostname Visibility</a>
            must be enabled on the network.

        Args:
            network_id (string): TODO: type description here. Example: 
            t_0 (string, optional): The beginning of the timespan for the
                data. The maximum lookback period is 30 days from today.
            timespan (float, optional): The timespan for which the information
                will be fetched. If specifying timespan, do not specify
                parameter t0. The value must be in seconds and be less than or
                equal to 30 days.
            device_type (string, optional): Filter the data by device type:
                combined (default), wireless, switch, appliance.     When
                using combined, for each rule the data will come from the
                device type with the most usage.

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/traffic'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            't0': t_0,
            'timespan': timespan,
            'deviceType': device_type
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def create_unbind_network(self,
                              network_id):
        """Does a POST request to /networks/{networkId}/unbind.

        Unbind a network from a template.

        Args:
            network_id (string): TODO: type description here. Example: 

        Returns:
            void: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/unbind'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.post(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

    def get_organization_networks(self,
                                  organization_id,
                                  config_template_id=None):
        """Does a GET request to /organizations/{organizationId}/networks.

        List the networks in an organization

        Args:
            organization_id (string): TODO: type description here. Example: 
            config_template_id (string, optional): An optional parameter that
                is the ID of a config template. Will return all networks bound
                to that template.

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/organizations/{organizationId}/networks'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'organizationId': organization_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            'configTemplateId': config_template_id
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def create_organization_network(self,
                                    organization_id,
                                    create_organization_network):
        """Does a POST request to /organizations/{organizationId}/networks.

        Create a network

        Args:
            organization_id (string): TODO: type description here. Example: 
            create_organization_network (CreateOrganizationNetwork): TODO:
                type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/organizations/{organizationId}/networks'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'organizationId': organization_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(create_organization_network))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def create_combine_organization_networks(self,
                                             organization_id,
                                             combine_organization_networks):
        """Does a POST request to /organizations/{organizationId}/networks/combine.

        Combine multiple networks into a single network

        Args:
            organization_id (string): TODO: type description here. Example: 
            combine_organization_networks (CombineOrganizationNetworks): TODO:
                type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/organizations/{organizationId}/networks/combine'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'organizationId': organization_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(combine_organization_networks))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body



# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class Server(object):

    """Implementation of the 'Server' model.

    TODO: type model description here.

    Attributes:
        host (string): The IP address of the syslog server
        port (int): The port of the syslog server
        roles (list of string): A list of roles for the syslog server. Options
            (case-insensitive): 'Wireless event log', 'Appliance event log',
            'Switch event log', 'Air Marshal events', 'Flows', 'URLs', 'IDS
            alerts', 'Security events'

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "host":'host',
        "port":'port',
        "roles":'roles'
    }

    def __init__(self,
                 host=None,
                 port=None,
                 roles=None):
        """Constructor for the Server class"""

        # Initialize members of the class
        self.host = host
        self.port = port
        self.roles = roles


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        host = dictionary.get('host')
        port = dictionary.get('port')
        roles = dictionary.get('roles')

        # Return an object of this model
        return cls(host,
                   port,
                   roles)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

import test_meraki.models.vendor_config

class UpdateNetworkSmProfileClarity(object):

    """Implementation of the 'updateNetworkSmProfileClarity' model.

    TODO: type model description here.

    Attributes:
        name (string): optional: A new name for the profile
        scope (string): optional: A new scope for the profile (one of all,
            none, withAny, withAll, withoutAny, or withoutAll) and a set of
            tags of the devices to be assigned
        plugin_bundle_id (string): optional: The new bundle ID of the
            application
        filter_browsers (bool): optional: Whether or not to enable browser
            traffic filtering (one of true, false).
        filter_sockets (bool): optional: Whether or not to enable socket
            traffic filtering (one of true, false).
        vendor_config (list of VendorConfig): optional: The specific
            VendorConfig to be passed to the filtering framework, in the form
            of an array of objects (as JSON).

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "name":'name',
        "scope":'scope',
        "plugin_bundle_id":'PluginBundleID',
        "filter_browsers":'FilterBrowsers',
        "filter_sockets":'FilterSockets',
        "vendor_config":'VendorConfig'
    }

    def __init__(self,
                 name=None,
                 scope=None,
                 plugin_bundle_id=None,
                 filter_browsers=None,
                 filter_sockets=None,
                 vendor_config=None):
        """Constructor for the UpdateNetworkSmProfileClarity class"""

        # Initialize members of the class
        self.name = name
        self.scope = scope
        self.plugin_bundle_id = plugin_bundle_id
        self.filter_browsers = filter_browsers
        self.filter_sockets = filter_sockets
        self.vendor_config = vendor_config


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        name = dictionary.get('name')
        scope = dictionary.get('scope')
        plugin_bundle_id = dictionary.get('PluginBundleID')
        filter_browsers = dictionary.get('FilterBrowsers')
        filter_sockets = dictionary.get('FilterSockets')
        vendor_config = None
        if dictionary.get('VendorConfig') != None:
            vendor_config = list()
            for structure in dictionary.get('VendorConfig'):
                vendor_config.append(test_meraki.models.vendor_config.VendorConfig.from_dictionary(structure))

        # Return an object of this model
        return cls(name,
                   scope,
                   plugin_bundle_id,
                   filter_browsers,
                   filter_sockets,
                   vendor_config)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""

from test_meraki.api_helper import APIHelper
from test_meraki.configuration import Configuration
from test_meraki.controllers.base_controller import BaseController
from test_meraki.http.auth.custom_header_auth import CustomHeaderAuth

class PIIController(BaseController):

    """A Controller to access Endpoints in the test_meraki API."""


    def get_network_pii_pii_keys(self,
                                 network_id,
                                 username=None,
                                 email=None,
                                 mac=None,
                                 serial=None,
                                 imei=None,
                                 bluetooth_mac=None):
        """Does a GET request to /networks/{networkId}/pii/piiKeys.

        List the keys required to access Personally Identifiable Information
        (PII) for a given identifier. Exactly one identifier will be accepted.
        If the organization contains org-wide Systems Manager users matching
        the key provided then there will be an entry with the key "0"
        containing the applicable keys.
        ## ALTERNATE PATH
        ```
        /organizations/{organizationId}/pii/piiKeys
        ```

        Args:
            network_id (string): TODO: type description here. Example: 
            username (string, optional): The username of a Systems Manager
                user
            email (string, optional): The email of a network user account or a
                Systems Manager device
            mac (string, optional): The MAC of a network client device or a
                Systems Manager device
            serial (string, optional): The serial of a Systems Manager device
            imei (string, optional): The IMEI of a Systems Manager device
            bluetooth_mac (string, optional): The MAC of a Bluetooth client

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/pii/piiKeys'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            'username': username,
            'email': email,
            'mac': mac,
            'serial': serial,
            'imei': imei,
            'bluetoothMac': bluetooth_mac
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_pii_requests(self,
                                 network_id):
        """Does a GET request to /networks/{networkId}/pii/requests.

        List the PII requests for this network or organization
        ## ALTERNATE PATH
        ```
        /organizations/{organizationId}/pii/requests
        ```

        Args:
            network_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/pii/requests'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def create_network_pii_request(self,
                                   network_id,
                                   create_network_pii_request=None):
        """Does a POST request to /networks/{networkId}/pii/requests.

        Submit a new delete or restrict processing PII request
        ## ALTERNATE PATH
        ```
        /organizations/{organizationId}/pii/requests
        ```

        Args:
            network_id (string): TODO: type description here. Example: 
            create_network_pii_request (CreateNetworkPiiRequest, optional):
                TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/pii/requests'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare headers
        _headers = {
            'content-type': 'application/json; charset=utf-8'
        }

        # Prepare and execute request
        _request = self.http_client.post(_query_url, headers=_headers, parameters=APIHelper.json_serialize(create_network_pii_request))
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_pii_request(self,
                                network_id,
                                request_id):
        """Does a GET request to /networks/{networkId}/pii/requests/{requestId}.

        Return a PII request
        ## ALTERNATE PATH
        ```
        /organizations/{organizationId}/pii/requests/{requestId}
        ```

        Args:
            network_id (string): TODO: type description here. Example: 
            request_id (string): TODO: type description here. Example: 

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/pii/requests/{requestId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'requestId': request_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def delete_network_pii_request(self,
                                   network_id,
                                   request_id):
        """Does a DELETE request to /networks/{networkId}/pii/requests/{requestId}.

        Delete a restrict processing PII request
        ## ALTERNATE PATH
        ```
        /organizations/{organizationId}/pii/requests/{requestId}
        ```

        Args:
            network_id (string): TODO: type description here. Example: 
            request_id (string): TODO: type description here. Example: 

        Returns:
            void: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/pii/requests/{requestId}'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id,
            'requestId': request_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.delete(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

    def get_network_pii_sm_devices_for_key(self,
                                           network_id,
                                           username=None,
                                           email=None,
                                           mac=None,
                                           serial=None,
                                           imei=None,
                                           bluetooth_mac=None):
        """Does a GET request to /networks/{networkId}/pii/smDevicesForKey.

        Given a piece of Personally Identifiable Information (PII), return the
        Systems Manager device ID(s) associated with that identifier. These
        device IDs can be used with the Systems Manager API endpoints to
        retrieve device details. Exactly one identifier will be accepted.
        ## ALTERNATE PATH
        ```
        /organizations/{organizationId}/pii/smDevicesForKey
        ```

        Args:
            network_id (string): TODO: type description here. Example: 
            username (string, optional): The username of a Systems Manager
                user
            email (string, optional): The email of a network user account or a
                Systems Manager device
            mac (string, optional): The MAC of a network client device or a
                Systems Manager device
            serial (string, optional): The serial of a Systems Manager device
            imei (string, optional): The IMEI of a Systems Manager device
            bluetooth_mac (string, optional): The MAC of a Bluetooth client

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/pii/smDevicesForKey'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            'username': username,
            'email': email,
            'mac': mac,
            'serial': serial,
            'imei': imei,
            'bluetoothMac': bluetooth_mac
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body

    def get_network_pii_sm_owners_for_key(self,
                                          network_id,
                                          username=None,
                                          email=None,
                                          mac=None,
                                          serial=None,
                                          imei=None,
                                          bluetooth_mac=None):
        """Does a GET request to /networks/{networkId}/pii/smOwnersForKey.

        Given a piece of Personally Identifiable Information (PII), return the
        Systems Manager owner ID(s) associated with that identifier. These
        owner IDs can be used with the Systems Manager API endpoints to
        retrieve owner details. Exactly one identifier will be accepted.
        ## ALTERNATE PATH
        ```
        /organizations/{organizationId}/pii/smOwnersForKey
        ```

        Args:
            network_id (string): TODO: type description here. Example: 
            username (string, optional): The username of a Systems Manager
                user
            email (string, optional): The email of a network user account or a
                Systems Manager device
            mac (string, optional): The MAC of a network client device or a
                Systems Manager device
            serial (string, optional): The serial of a Systems Manager device
            imei (string, optional): The IMEI of a Systems Manager device
            bluetooth_mac (string, optional): The MAC of a Bluetooth client

        Returns:
            object: Response from the API. Successful operation

        Raises:
            APIException: When an error occurs while fetching the data from
                the remote API. This exception includes the HTTP Response
                code, an error message, and the HTTP body that was received in
                the request.

        """

        # Prepare query URL
        _url_path = '/networks/{networkId}/pii/smOwnersForKey'
        _url_path = APIHelper.append_url_with_template_parameters(_url_path, { 
            'networkId': network_id
        })
        _query_builder = Configuration.base_uri
        _query_builder += _url_path
        _query_parameters = {
            'username': username,
            'email': email,
            'mac': mac,
            'serial': serial,
            'imei': imei,
            'bluetoothMac': bluetooth_mac
        }
        _query_builder = APIHelper.append_url_with_query_parameters(_query_builder,
            _query_parameters, Configuration.array_serialization)
        _query_url = APIHelper.clean_url(_query_builder)

        # Prepare and execute request
        _request = self.http_client.get(_query_url)
        CustomHeaderAuth.apply(_request)
        _context = self.execute_request(_request)
        self.validate_response(_context)

        # Return appropriate type
        return _context.response.raw_body



# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class UpdateNetworkSsidSplashSettings(object):

    """Implementation of the 'updateNetworkSsidSplashSettings' model.

    TODO: type model description here.

    Attributes:
        splash_url (string): [optional] The custom splash URL of the
            click-through splash page. Note that the URL can be configured
            without necessarily being used. In order to enable the custom URL,
            see 'useSplashUrl'
        use_splash_url (bool): [optional] Boolean indicating whether the user
            will be redirected to the custom splash url. A custom splash URL
            must be set if this is true. Note that depending on your SSID's
            access control settings, it may not be possible to use the custom
            splash URL.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "splash_url":'splashUrl',
        "use_splash_url":'useSplashUrl'
    }

    def __init__(self,
                 splash_url=None,
                 use_splash_url=None):
        """Constructor for the UpdateNetworkSsidSplashSettings class"""

        # Initialize members of the class
        self.splash_url = splash_url
        self.use_splash_url = use_splash_url


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        splash_url = dictionary.get('splashUrl')
        use_splash_url = dictionary.get('useSplashUrl')

        # Return an object of this model
        return cls(splash_url,
                   use_splash_url)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class BindNetwork(object):

    """Implementation of the 'bindNetwork' model.

    TODO: type model description here.

    Attributes:
        config_template_id (string): The ID of the template to which the
            network should be bound.
        auto_bind (bool): Optional boolean indicating whether the network's
            switches should automatically bind to profiles of the same model.
            Defaults to false if left unspecified. This option only affects
            switch networks and switch templates. Auto-bind is not valid
            unless the switch template has at least one profile and has at
            most one profile per switch model.

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "config_template_id":'configTemplateId',
        "auto_bind":'autoBind'
    }

    def __init__(self,
                 config_template_id=None,
                 auto_bind=None):
        """Constructor for the BindNetwork class"""

        # Initialize members of the class
        self.config_template_id = config_template_id
        self.auto_bind = auto_bind


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        config_template_id = dictionary.get('configTemplateId')
        auto_bind = dictionary.get('autoBind')

        # Return an object of this model
        return cls(config_template_id,
                   auto_bind)





# -*- coding: utf-8 -*-

"""
    test_meraki

    This file was automatically generated by APIMATIC v2.0 ( https://apimatic.io ).
"""


class RenewOrganizationLicensesSeats(object):

    """Implementation of the 'renewOrganizationLicensesSeats' model.

    TODO: type model description here.

    Attributes:
        license_id_to_renew (string): The ID of the SM license to renew. This
            license must already be assigned to an SM network
        unused_license_id (string): The SM license to use to renew the seats
            on 'licenseIdToRenew'. This license must have at least as many
            seats available as there are seats on 'licenseIdToRenew'

    """

    # Create a mapping from Model property names to API property names
    _names = {
        "license_id_to_renew":'licenseIdToRenew',
        "unused_license_id":'unusedLicenseId'
    }

    def __init__(self,
                 license_id_to_renew=None,
                 unused_license_id=None):
        """Constructor for the RenewOrganizationLicensesSeats class"""

        # Initialize members of the class
        self.license_id_to_renew = license_id_to_renew
        self.unused_license_id = unused_license_id


    @classmethod
    def from_dictionary(cls,
                        dictionary):
        """Creates an instance of this model from a dictionary

        Args:
            dictionary (dictionary): A dictionary representation of the object as
            obtained from the deserialization of the server's response. The keys
            MUST match property names in the API description.

        Returns:
            object: An instance of this structure class.

        """
        if dictionary is None:
            return None

        # Extract variables from the dictionary
        license_id_to_renew = dictionary.get('licenseIdToRenew')
        unused_license_id = dictionary.get('unusedLicenseId')

        # Return an object of this model
        return cls(license_id_to_renew,
                   unused_license_id)


